Route path constants.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const List<
String> - All registered patterns, most specific first.
- login → const String
- Login screen.
- nodeDetail → const String
-
Node detail —
:id. - nodes → const String
- Node list (the connected home).
- nodeSessions → const String
-
Sessions for a node —
:id. - sessionView → const String
-
Interactive view of one session —
:id(node),:sid(session).