start method
void
start()
Begins listening for hashchange and emits the initial route.
Implementation
void start() {
_detach = on(_window, 'hashchange', (_) => _sync());
_sync();
}
Begins listening for hashchange and emits the initial route.
void start() {
_detach = on(_window, 'hashchange', (_) => _sync());
_sync();
}