LocalStorageStore class
A KeyValueStore backed by the browser's window.localStorage.
- Implemented types
Constructors
- LocalStorageStore([Storage? storage])
-
Creates a store over
storage(defaults towindow.localStorage).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String key) → String? -
Returns the value for
key, ornullif absent.override -
remove(
String key) → void -
Removes
keyif present.override -
removeWhereKeyStartsWith(
String prefix) → void -
Removes every key beginning with
prefix.override -
toString(
) → String -
A string representation of this object.
inherited
-
write(
String key, String value) → void -
Stores
valueunderkey.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited