openSettings property
void Function()
openSettings
final
Opens the settings panel so the user can configure AI.
Implementation
final void Function() openSettings;
Opens the settings panel so the user can configure AI.
final void Function() openSettings;