DeviceMetrics class

A device's screen boxes in both orientations, used to suggest fitting dimensions regardless of how the device is currently held.

Constructors

DeviceMetrics({required OrientationBox portrait, required OrientationBox landscape})
Creates metrics from a portrait and landscape box.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
landscape OrientationBox
The landscape (wide) box.
final
portrait OrientationBox
The portrait (tall) box.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited