terminalFactory property
Builds the terminal surface inside the given host element.
Implementation
final TerminalView Function(web.HTMLElement host) terminalFactory;
Builds the terminal surface inside the given host element.
final TerminalView Function(web.HTMLElement host) terminalFactory;