AuthSnapshot class
An immutable snapshot of auth state, rendered by the UI.
Constructors
- AuthSnapshot({required AuthStatus status, Principal? principal, String? hubUri, AppError? error})
-
Creates a snapshot.
const
- AuthSnapshot.signedOut()
-
The initial signed-out snapshot.
const
Properties
- error → AppError?
-
The failure when status is AuthStatus.error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hubUri → String?
-
The Hub URL of the active/last connection.
final
- isConnected → bool
-
Whether the user is connected.
no setter
- principal → Principal?
-
The authenticated principal when status is AuthStatus.connected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthStatus
-
The lifecycle status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited