TerminalKeys class abstract
The key-input surface the on-screen accessory bar drives: inject raw key sequences and toggle a sticky Ctrl modifier. Implemented by WebShellHost.
- Implementers
Constructors
Properties
- ctrlArmed → bool
-
Whether the sticky Ctrl modifier is armed.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCtrlChange ← void Function(bool armed)?
-
Set a callback notified when the Ctrl modifier arms/disarms.
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
armCtrl(
) → void - Toggles the sticky Ctrl modifier.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendKey(
List< int> bytes) → void -
Injects
bytesas if the user typed them. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited